from typing import Union

from gbox_sdk.wrapper.box.linux import LinuxBoxOperator
from gbox_sdk.types.v1.boxes.dir import Dir
from gbox_sdk.types.v1.linux_box import LinuxBox
from gbox_sdk.types.v1.boxes.file import File
from gbox_sdk.types.v1.android_box import AndroidBox
from gbox_sdk.wrapper.box.file_system import FileOperator, DirectoryOperator
from gbox_sdk.wrapper.box.android.android import AndroidBoxOperator


def is_android_box(box: Union[AndroidBox, LinuxBox]) -> bool:
    return getattr(box, "type", None) == "android"


def is_linux_box(box: Union[AndroidBox, LinuxBox]) -> bool:
    return getattr(box, "type", None) == "linux"


def is_android_operator(operator: Union[AndroidBoxOperator, LinuxBoxOperator]) -> bool:
    return operator.data.type == "android"


def is_linux_operator(operator: Union[AndroidBoxOperator, LinuxBoxOperator]) -> bool:
    return operator.data.type == "linux"


def is_file(item: Union[File, Dir]) -> bool:
    return item.type == "file"


def is_directory(item: Union[File, Dir]) -> bool:
    return item.type == "dir"


def is_file_operator(item: Union[FileOperator, DirectoryOperator]) -> bool:
    return item.data.type == "file"


def is_directory_operator(item: Union[FileOperator, DirectoryOperator]) -> bool:
    return item.data.type == "dir"



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal, Required, Annotated, TypedDict

from ...._utils import PropertyInfo
from .action_common_options_param import ActionCommonOptionsParam

__all__ = ["ActionPressButtonParams"]


class ActionPressButtonParams(TypedDict, total=False):
    buttons: Required[
        List[Literal["power", "volumeUp", "volumeDown", "volumeMute", "home", "back", "menu", "appSwitch"]]
    ]
    """Button to press"""

    include_screenshot: Annotated[bool, PropertyInfo(alias="includeScreenshot")]
    """⚠️ DEPRECATED: Use `options.screenshot.phases` instead.

    This field will be ignored when `options.screenshot` is provided. Whether to
    include screenshots in the action response. If false, the screenshot object will
    still be returned but with empty URIs. Default is false.
    """

    options: ActionCommonOptionsParam
    """Action common options"""

    output_format: Annotated[Literal["base64", "storageKey"], PropertyInfo(alias="outputFormat")]
    """⚠️ DEPRECATED: Use `options.screenshot.outputFormat` instead.

    Type of the URI. default is base64. This field will be ignored when
    `options.screenshot` is provided.
    """

    presigned_expires_in: Annotated[str, PropertyInfo(alias="presignedExpiresIn")]
    """⚠️ DEPRECATED: Use `options.screenshot.presignedExpiresIn` instead.

    Presigned url expires in. Only takes effect when outputFormat is storageKey.
    This field will be ignored when `options.screenshot` is provided.

    Supported time units: ms (milliseconds), s (seconds), m (minutes), h (hours)
    Example formats: "500ms", "30s", "5m", "1h" Default: 30m
    """

    screenshot_delay: Annotated[str, PropertyInfo(alias="screenshotDelay")]
    """⚠️ DEPRECATED: Use `options.screenshot.delay` instead.

    This field will be ignored when `options.screenshot` is provided.

    Delay after performing the action, before taking the final screenshot.

    Execution flow:

    1. Take screenshot before action
    2. Perform the action
    3. Wait for screenshotDelay (this parameter)
    4. Take screenshot after action

    Example: '500ms' means wait 500ms after the action before capturing the final
    screenshot.

    Supported time units: ms (milliseconds), s (seconds), m (minutes), h (hours)
    Example formats: "500ms", "30s", "5m", "1h" Default: 500ms Maximum allowed: 30s
    """
